# OKING - OkVendas
Sistema python para realizar a integração entre ERP's e a solução OkVendas da Openk.

Dentre os módulos de integração estão:
- Preço
- Estoque
- Pedido
- Produtos
- Clientes

## Manual
<https://doc.clickup.com/d/h/2zgwt-5063/8b4903a4de0ccbd>

## Fluxo de trabaho utilizando GIT Flow

Utilizar GIT Flow como padrão de desenvolvimento dos projetos deste repositório. Para mais informações acesse o link abaixo:

[GIT Flow - Fluxo de trabalho](https://www.atlassian.com/br/git/tutorials/comparing-workflows/gitflow-workflow)

Sempre realizar o pull da branch 'develop' antes de iniciar uma atividade.

Após o pull realizado, dar start em uma nova feature através do comando 'git flow feature start {nome-feature}'.

Realizar os commits na nova branch criada.

____________________________________________________________________________________________________________________________

Vídeo explicativo sobre o GIT Flow:

[GIT - GIT Flow na prática](https://www.youtube.com/watch?v=wzxBR4pOTTs)

____________________________________________________________________________________________________________________________
